#' Ozone Readings from Eskdalemuir, for 1994 and 1995
#' 
#' Hourly ozone readings in parts per billion (ppb) from Eskdalemuir,
#'   Scotland, for 1994 and 1995
#' @name ozone
#' @docType data
#' @format Data frame with the following 25 variables: 
#' \describe{
#'   \item{date}{date (day/month/year)}
#'   \item{GMT1}{ozone reading at 1:00 GMT}
#'   \item{GMT2}{ozone reading at 2:00 GMT}
#'   \item{GMT3}{ozone reading at 3:00 GMT}
#'   \item{GMT4}{ozone reading at 4:00 GMT}
#'   \item{GMT5}{ozone reading at 5:00 GMT}
#'   \item{GMT6}{ozone reading at 6:00 GMT}
#'   \item{GMT7}{ozone reading at 7:00 GMT}
#'   \item{GMT8}{ozone reading at 8:00 GMT}
#'   \item{GMT9}{ozone reading at 9:00 GMT}
#'   \item{GMT10}{ozone reading at 10:00 GMT}
#'   \item{GMT11}{ozone reading at 11:00 GMT}
#'   \item{GMT12}{ozone reading at 12:00 GMT}
#'   \item{GMT13}{ozone reading at 13:00 GMT}
#'   \item{GMT14}{ozone reading at 14:00 GMT}
#'   \item{GMT15}{ozone reading at 15:00 GMT}
#'   \item{GMT16}{ozone reading at 16:00 GMT}
#'   \item{GMT17}{ozone reading at 17:00 GMT}
#'   \item{GMT18}{ozone reading at 18:00 GMT}
#'   \item{GMT19}{ozone reading at 19:00 GMT}
#'   \item{GMT20}{ozone reading at 20:00 GMT}
#'   \item{GMT21}{ozone reading at 21:00 GMT}
#'   \item{GMT22}{ozone reading at 22:00 GMT}
#'   \item{GMT23}{ozone reading at 23:00 GMT}
#'   \item{GMT24}{ozone reading at 24:00 GMT}
#' }
#' @source Air Quality Information Centre: retrieved from a now defunct URL (http://www.aeat.co.uk)
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   443.
"ozone"